/**
 * Copyright 2008 by jFramework.org.
 */
package org.jframework.core.util;

import junit.framework.TestCase;

import java.util.Locale;

import org.easymock.EasyMock;

/**
 * Locale aware container test.
 *
 * @author mgridnev
 * @version 1.0, Jun 10, 2008
 */
public class LocaleAwareContainerTest extends TestCase
{
    /**
     * Container being tested.
     */
    private LocaleAwareContainer container;

    /**
     * {@inheritDoc}
     */
    protected void setUp() throws Exception
    {
        super.setUp();

        container = new LocaleAwareContainer();
    }

    /**
     * Tests time zone propagation to children.
     */
    public void testLocalePropagation()
    {
        // Set initial time zone
        Locale locale = Locale.CANADA;
        container.setLocale(locale);

        // Add child
        final LocaleAware child = EasyMock.createMock(LocaleAware.class);
        child.setLocale(locale); // initial add
        EasyMock.replay(child);

        container.addChild(child);

        EasyMock.verify(child);

        // Change time zone
        EasyMock.reset(child);

        locale = Locale.US;
        child.setLocale(locale);

        EasyMock.replay(child);

        container.setLocale(locale);

        EasyMock.verify(child);

        // No effect
        EasyMock.reset(child);
        EasyMock.replay(child);

        container.setLocale(locale);

        EasyMock.verify(child);

        // Remove child
        EasyMock.reset(child);
        EasyMock.replay(child);

        container.removeChild(child);

        locale = Locale.UK;
        container.setLocale(locale);

        EasyMock.verify(child);
    }
}
