/**
 * Copyright 2008 by jFramework.org.
 */
package org.jframework.core.util;

import junit.framework.TestCase;

import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * A base for tests that need to load external resources {@link Resources}.
 *
 * @author mgridnev
 * @version 1.0, Jun 1, 2008
 */
public abstract class ResourcesTestCase extends TestCase
{
    /**
     * Resource.
     */
    protected Resources resources;

    /**
     * Sets up a test run
     */
    protected final void setUp() throws Exception
    {
        resources = createResource();

        final Map<String, ResourceBundle> bundles = resources.getBundles();

        // Init new mappings
        final Mapping[] mappings = createMappings();
        for (Mapping mapping : mappings) {
            bundles.put(mapping.context, mapping.bundle);
        }

        onResourceSetUp();
    }

    /**
     * Creates a resource.
     *
     * @return returns a resource for a default locale
     */
    protected Resources createResource()
    {
        return new Resources(Locale.getDefault());
    }

    /**
     * Returns resource mappings applicable to this test case
     */
    protected abstract Mapping[] createMappings();

    /**
     * Sets up a test run
     */
    protected void onResourceSetUp() throws Exception
    {
    }

    /**
     * Cleans up after test run
     */
    protected final void tearDown() throws Exception
    {
        onResourceTearDown();
    }

    /**
     * Cleans up after test run
     */
    protected void onResourceTearDown() throws Exception
    {
    }

    /**
     * Resource bundle to context name mapping
     */
    protected static class Mapping
    {
        /**
         * Context name
         */
        final String context;

        /**
         * Resource bundle
         */
        final ResourceBundle bundle;

        /**
         * Creates a mapping
         *
         * @param context resource context name
         * @param bundle  bundle
         */
        public Mapping(final String context, final ResourceBundle bundle)
        {
            this.context = context;
            this.bundle = bundle;
        }
    }
}
