/**
 * Copyright 2008 by jFramework.org.
 */
package org.jframework.core.util;

import junit.framework.TestCase;

import java.util.TimeZone;

import org.easymock.EasyMock;
import static org.easymock.EasyMock.*;

/**
 * Time zone aware container test.
 *
 * @author mgridnev
 * @version 1.0, Jun 10, 2008
 */
public class TimeZoneAwareContainerTest extends TestCase
{
    /**
     * Container being tested.
     */
    private TimeZoneAwareContainer container;

    /**
     * {@inheritDoc}
     */
    protected void setUp() throws Exception
    {
        super.setUp();

        container = new TimeZoneAwareContainer();
    }

    /**
     * Tests time zone propagation to children.
     */
    public void testTimeZonePropagation()
    {
        // Set initial time zone
        TimeZone timeZone = TimeZone.getTimeZone("EST");
        container.setTimeZone(timeZone);

        // Add child
        final TimeZoneAware child = EasyMock.createMock(TimeZoneAware.class);
        child.setTimeZone(timeZone); // initial add
        replay(child);

        container.addChild(child);

        verify(child);

        // Change time zone
        reset(child);

        timeZone = TimeZone.getTimeZone("MST");
        child.setTimeZone(timeZone);

        replay(child);

        container.setTimeZone(timeZone);

        verify(child);

        // No effect
        reset(child);
        replay(child);

        container.setTimeZone(timeZone);

        verify(child);

        // Remove child
        reset(child);
        replay(child);

        container.removeChild(child);

        timeZone = TimeZone.getTimeZone("PST");
        container.setTimeZone(timeZone);

        verify(child);
    }
}
